@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef MULTISELECTLISTVIEW_H
 #define MULTISELECTLISTVIEW_H
 
@@ -19,7 +23,7 @@ protected:
     void currentChanged(const QModelIndex &current, const QModelIndex &previous) override;
     QModelIndex moveCursor(CursorAction cursorAction, Qt::KeyboardModifiers modifiers) override;
     void keyPressEvent(QKeyEvent *event) override;
-
+    void mousePressEvent(QMouseEvent *event) override;
 private:
     int m_currentIndex;
 };
