@@ -1,27 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "monitorsground.h"
 #include "monitorproxywidget.h"
@@ -77,6 +56,8 @@ MonitorsGround::MonitorsGround(int activateHeight, QWidget *parent)
     m_effectiveTimer->setInterval(m_nEffectiveTime*1000);
     m_effectiveTimer->setSingleShot(true);
     connect(m_effectiveTimer, &QTimer::timeout, this, [=]() {
+        m_nEffectiveTime = 2;
+        m_effectiveTimer->setInterval(m_nEffectiveTime*1000);
         Q_EMIT setEffectiveReminderVisible(false, m_nEffectiveTime);
         for (auto mon : m_model->monitorList()) {
             disconnect(mon, &Monitor::geometryChanged, this, &MonitorsGround::onGeometryChanged);
@@ -139,7 +120,7 @@ void MonitorsGround::setModel(DisplayModel *model, Monitor *moni)
     QTimer::singleShot(1, this, [=](){
         if (!m_isSingleDisplay) {
             updateScale();
-        }    
+        }
         resetMonitorsView();
     });
 }
@@ -197,7 +178,7 @@ void MonitorsGround::onRotateChanged()
 
 //当方向改变时 当分辨率改变时
 void MonitorsGround::onCurrentModeChanged()
-{    
+{
     onResize();
     if (m_setMergeMode || m_isSingleDisplay)
         return;
@@ -211,7 +192,7 @@ void MonitorsGround::onCurrentModeChanged()
           }
     }
 
-   executemultiScreenAlgo(false);
+    executemultiScreenAlgo(false);
 }
 
 
@@ -237,6 +218,8 @@ void MonitorsGround::executemultiScreenAlgo(const bool isRebound)
     updateConnectedState();
 
     //显示设置生效倒计时提示框
+    m_nEffectiveTime = isRebound ? 2 : 0;
+    m_effectiveTimer->setInterval(m_nEffectiveTime * 1000);
     Q_EMIT setEffectiveReminderVisible(true, m_nEffectiveTime);
     m_effectiveTimer->start();
 }
@@ -490,8 +473,12 @@ QPointF MonitorsGround::multiScreenSortAlgo(bool &isRestore, const bool isReboun
             QRectF rect = moveItemIntersect.intersected(m_lstSortItems[i]->mapRectToScene(m_lstSortItems[i]->boundingRect()));
             intersectedArea += rect.width()*rect.height();
 
-            //移动块完全覆盖一个块
-            if (moveItemRect.contains(m_lstSortItems[i]->mapRectToScene(m_lstSortItems[i]->boundingRect()))) {
+            qInfo() << "rect" << rect << "moveItemRect" << moveItemRect << "moveItemIntersect" << moveItemIntersect;
+
+            //1、移动块完全覆盖一个块 2、移动块与另外一个块十字相交时 执行自动回弹操作
+            if (moveItemRect.contains(m_lstSortItems[i]->mapRectToScene(m_lstSortItems[i]->boundingRect()))
+                    || (rect.top() < moveItemIntersect.top() && rect.bottom() > moveItemIntersect.bottom() && qFuzzyCompare(rect.left(), moveItemIntersect.left()) && qFuzzyCompare(rect.right(), moveItemIntersect.right()))
+                    || (rect.right() < moveItemIntersect.right() && rect.left() > moveItemIntersect.left() && qFuzzyCompare(rect.top(), moveItemIntersect.top()) && qFuzzyCompare(rect.bottom(), moveItemIntersect.bottom()))) {
                 lstShelterItems.append(m_lstSortItems[i]);
             }
 
@@ -1344,6 +1331,8 @@ void MonitorsGround::onRequestKeyPress(MonitorProxyWidget *pw, int keyValue)
     updateConnectedState();
     onResize();
 
+    m_nEffectiveTime = 2;
+    m_effectiveTimer->setInterval(m_nEffectiveTime * 1000);
     Q_EMIT setEffectiveReminderVisible(true, m_nEffectiveTime);
     m_effectiveTimer->start();
 }
@@ -1503,12 +1492,12 @@ void MonitorsGround::updateScale()
 
 void MonitorsGround::autoRebound()
 {
-
     for (auto pw : m_monitors.keys()) {
         //设置位置
         pw->setPos(pw->getPreCenter());
         pw->update();
     }
+    onResize();
 }
 
 //屏幕示意图平移居中
