@@ -1,32 +1,12 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "personalizationmodel.h"
 #include "model/thememodel.h"
 #include "model/fontmodel.h"
 #include "model/fontsizemodel.h"
+#include "window/dconfigwatcher.h"
 
 using namespace dcc;
 using namespace dcc::personalization;
@@ -78,6 +58,16 @@ bool PersonalizationModel::isMoveWindow() const
     return m_isMoveWindow;
 }
 
+bool PersonalizationModel::getIsMoveWindowDconfig()
+{
+    return DConfigWatcher::instance()->getValue(DConfigWatcher::ModuleType::personalization, "effectMoveWindowTranslucencyStatus").toBool();
+}
+
+void PersonalizationModel::setIsMoveWindowDconfig(bool value)
+{
+    DConfigWatcher::instance()->setValue(DConfigWatcher::ModuleType::personalization, "effectMoveWindowTranslucencyStatus", QVariant(value));
+}
+
 void PersonalizationModel::setWindowRadius(int radius)
 {
     if (m_windowRadius != radius)
