@@ -1,27 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             kirigaya <kirigaya@mkacg.com>
- *             Hualet <mr.asianwang@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "updatework.h"
 #include "window/utils.h"
@@ -573,6 +552,7 @@ void UpdateWorker::requestUpdateLog()
     // TODO 增加过滤参数，避免每次请求全量更新日志，这个需要web端配合
     QJsonObject requestBody;
     requestBody["platformType"] = getPlatform();
+    requestBody["isUnstable"] = isUnstableResource();
     QJsonDocument doc;
     doc.setObject(requestBody);
     const QByteArray &body = doc.toJson();
@@ -1936,5 +1916,32 @@ void UpdateWorker::setUpdateLogs(const QJsonArray &array)
     });
 }
 
+/**
+ * @brief 发行版or内测版
+ *
+ * @return 1: 发行版，2：内测版
+ */
+int UpdateWorker::isUnstableResource() const
+{
+    qInfo() << Q_FUNC_INFO;
+    const int RELEASE_VERSION = 1;
+    const int UNSTABLE_VERSION = 2;
+    QObject raii;
+    DConfig *config = DConfig::create("org.deepin.unstable", "org.deepin.unstable", QString(), &raii);
+    if (!config) {
+        qInfo() << "Can not find org.deepin.unstable or an error occurred in DTK";
+        return RELEASE_VERSION;
+    }
+
+    if (!config->keyList().contains("updateUnstable")) {
+        qInfo() << "Key(updateUnstable) was not found ";
+        return RELEASE_VERSION;
+    }
+
+    const QString &value = config->value("updateUnstable", "Enabled").toString();
+    qInfo() << "Config(updateUnstable) value: " << value;
+    return "Enabled" == value ? UNSTABLE_VERSION : RELEASE_VERSION;
+}
+
 }
 }
