@@ -1,26 +1,10 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     duanhongyu <duanhongyu@uniontech.com>
-
- * Maintainer: duanhongyu <duanhongyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "widgets/buttoneditwidget.h"
 #include "widgets/lineeditwidget.h"
+#include "window/utils.h"
 
 #include <dpasswordedit.h>
 #include <QVBoxLayout>
@@ -38,7 +22,7 @@ ButtonEditWidget::ButtonEditWidget(QFrame *parent)
     , m_addBtn(new DIconButton(DStyle::SP_AddButton, this))
     , m_reduceBtn(new DIconButton(DStyle::SP_DeleteButton, this))
 {
-    m_title->setFixedWidth(110);
+    m_title->setMinimumWidth(DCC_NAMESPACE::LeftTitleWitdh);
     m_edit->setContextMenuPolicy(Qt::NoContextMenu);
 
     m_addBtn->setFixedSize(QSize(19, 19));
@@ -47,12 +31,14 @@ ButtonEditWidget::ButtonEditWidget(QFrame *parent)
     m_reduceBtn->setFixedSize(QSize(19, 19));
     m_reduceBtn->setIconSize(QSize(17, 17));
 
-    m_mainLayout = new QHBoxLayout;
+    QHBoxLayout *rightLayout = new QHBoxLayout;
+    rightLayout->addWidget(m_edit, 0, Qt::AlignVCenter);
+    rightLayout->addWidget(m_addBtn, 0, Qt::AlignVCenter);
+    rightLayout->addWidget(m_reduceBtn, 0, Qt::AlignVCenter);
 
-    m_mainLayout->addWidget(m_title, 0, Qt::AlignVCenter);
-    m_mainLayout->addWidget(m_edit, 0, Qt::AlignVCenter);
-    m_mainLayout->addWidget(m_addBtn, 0, Qt::AlignVCenter);
-    m_mainLayout->addWidget(m_reduceBtn, 0, Qt::AlignVCenter);
+    m_mainLayout = new QHBoxLayout;
+    m_mainLayout->addWidget(m_title, 3, Qt::AlignVCenter);
+    m_mainLayout->addLayout(rightLayout, 7);
 
     setLayout(m_mainLayout);
     setObjectName("ButtonEditWidget");
