@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "widgets/multiselectlistview.h"
 
 #include <QKeyEvent>
@@ -67,5 +71,11 @@ void MultiSelectListView::keyPressEvent(QKeyEvent *event)
     return DListView::keyPressEvent(event);
 }
 
+void MultiSelectListView::mousePressEvent(QMouseEvent *event)
+{
+    if (event->button() != Qt::LeftButton)
+        return;
+    return DListView::mousePressEvent(event);
+}
 }
 }
