@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef DISABLE_AUTHENTICATION
 #include "modules/authentication/loginoptionsmodule.h"
 #endif
@@ -164,6 +148,9 @@ MainWindow::MainWindow(QWidget *parent)
     m_searchWidget->lineEdit()->setAccessibleName("SearchModuleLineEdit");
     GSettingWatcher::instance()->bind("mainwindowSearchEdit", m_searchWidget);
 
+    m_currentIndex.first = m_navView->viewMode();
+    m_currentIndex.second = m_navView->currentIndex();
+
     DTitlebar *titlebar = this->titlebar();
     auto widhetlist = titlebar->children();
     for (auto child : widhetlist) {
@@ -768,6 +755,16 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
             openManual();
             return true;
         }
+    } else if (event->type() == QEvent::MouseButtonRelease) {
+        QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
+        if (mouseEvent->button() == Qt::MouseButton::LeftButton) {
+            if (m_currentIndex.first != m_navView->viewMode() ||
+                m_currentIndex.second != m_navView->currentIndex()) {
+                m_currentIndex.first = m_navView->viewMode();
+                m_currentIndex.second = m_navView->currentIndex();
+                onFirstItemClick(m_currentIndex.second);
+            }
+        }
     }
 
     return  DMainWindow::eventFilter(watched, event);
@@ -1238,6 +1235,10 @@ void MainWindow::updateViewBackground()
 
 void MainWindow::onFirstItemClick(const QModelIndex &index)
 {
+    if (index.row() < 0 || !m_modules[index.row()].first) {
+        return;
+    }
+
     ModuleInterface *inter = m_modules[index.row()].first;
 
     if (!m_contentStack.isEmpty() && m_contentStack.first().first == inter) {
