@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     liuhong <liuhong_cm@deepin.com>
- *
- * Maintainer: liuhong <liuhong_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #pragma once
 
@@ -48,15 +31,10 @@ class QVBoxLayout;
 class QHBoxLayout;
 class QPushButton;
 class QLabel;
+class QLocalServer;
+class QLocalSocket;
 QT_END_NAMESPACE
 
-
-namespace dcc {
-namespace widgets {
-class SecurityLevelItem;
-}
-}
-
 namespace DCC_NAMESPACE {
 namespace accounts {
 //修改密码页面
@@ -98,6 +76,7 @@ Q_SIGNALS:
 public Q_SLOTS:
     void onLocalBindCheckUbid(const QString &ubid);
     void onLocalBindCheckError(const QString &error);
+    void onNewConnection();
 
 private:
     dcc::accounts::User *m_curUser;
@@ -108,8 +87,9 @@ private:
     DTK_WIDGET_NAMESPACE::DLineEdit *m_passwordTipsEdit;
     bool m_isCurrent;
     bool m_isBindCheckError;
-    dcc::widgets::SecurityLevelItem *m_securityLevelItem;
     QTimer m_enableBtnTimer;
+    QLocalServer *m_localServer;
+    QLocalSocket *m_client;
 };
 }
 }
