@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     huangweihua <huangweihua@uniontech.com>
- *
- * Maintainer: huangweihua <huangweihua@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "multiscreenwidget.h"
 #include "brightnesswidget.h"
@@ -65,7 +48,6 @@ MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     , m_refreshRateWidget(new RefreshRateWidget(300, this))
     , m_rotateWidget(new RotateWidget(300, this))
     , m_model(nullptr)
-    , m_resetSecondaryScreenDlgTimer(new QTimer(this))
 {
     //初始化列表无法进行静态翻译
     //~ contents_path /display/Multiple Displays
@@ -138,9 +120,6 @@ MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     QDesktopWidget *desktopwidget = QApplication::desktop();
     connect(desktopwidget,SIGNAL(workAreaResized(int)),this,SLOT(onResetSecondaryScreenDlg()));
 
-    m_resetSecondaryScreenDlgTimer->setSingleShot(true);
-    m_resetSecondaryScreenDlgTimer->setInterval(100);
-    connect(m_resetSecondaryScreenDlgTimer, &QTimer::timeout, this, &MultiScreenWidget::onResetSecondaryScreenDlgTimerOut);
 }
 
 MultiScreenWidget::~MultiScreenWidget()
@@ -387,7 +366,6 @@ void MultiScreenWidget::initPrimaryList()
 void MultiScreenWidget::initSecondaryScreenDialog()
 {
     if (m_model->displayMode() == EXTEND_MODE) {
-        m_resetSecondaryScreenDlgTimer->stop();
         for (auto dlg : m_secondaryScreenDlgList) {
             dlg->deleteLater();
         }
@@ -426,14 +404,11 @@ void MultiScreenWidget::initSecondaryScreenDialog()
         activateWindow();
 
         if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
-            m_resetSecondaryScreenDlgTimer->start();
             QTimer::singleShot(10, this, [=] {
                 for (auto dlg : m_secondaryScreenDlgList) {
                     dlg->show();
                 }
             });
-        } else {
-            onResetSecondaryScreenDlgTimerOut();
         }
     }
 }
@@ -512,20 +487,12 @@ void MultiScreenWidget::onResetFullIndication(const QRect &geometry)
     m_fullIndication->move(geometry.topLeft());
 }
 
-void MultiScreenWidget::onResetSecondaryScreenDlgTimerOut()
-{
-    for (auto dlg : m_secondaryScreenDlgList) {
-        dlg->resetDialog();
-    }
-}
-
 void MultiScreenWidget::onResetSecondaryScreenDlg()
 {
     for (int i = 0; i < m_secondaryScreenDlgList.count(); ++i) {
         SecondaryScreenDialog *screenDialog = m_secondaryScreenDlgList.at(i);
         Q_ASSERT(screenDialog);
         screenDialog->setWindowOpacity(1);
-        screenDialog->resetDialog();
     }
 }
 
