@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     andywang <andywang_cm@deepin.com>
- *
- * Maintainer: andywang <andywang_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "shortcutsettingwidget.h"
 #include "window/utils.h"
@@ -28,8 +11,8 @@
 #include "widgets/settingsheaderitem.h"
 #include "widgets/settingsgroup.h"
 #include "widgets/searchinput.h"
-#include "window/utils.h"
 #include "window/gsettingwatcher.h"
+#include "waylandgrab.h"
 
 #include <DAnchors>
 
@@ -46,9 +29,10 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     , m_workspaceGroup(nullptr)
     , m_assistiveToolsGroup(nullptr)
     , m_model(model)
+    , m_waylandGrab(nullptr)
 {
     if (QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
-        waylandGrab = new WaylandGrab(this->parent());
+        m_waylandGrab = new WaylandGrab(this->parent());
     }
 
     setAccessibleName("ShortCutSettingWidget");
@@ -171,6 +155,7 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     vlayout->addLayout(btnLayout);
     vlayout->setContentsMargins(10, 10, 0, 5);
     setLayout(vlayout);
+    setFocusPolicy(Qt::FocusPolicy::ClickFocus);
 
     connect(m_addCustomShortcut, &DFloatingButton::clicked, this, &ShortCutSettingWidget::customShortcut);
 
@@ -257,6 +242,12 @@ void ShortCutSettingWidget::addShortcut(QList<ShortcutInfo *> list, ShortcutMode
         ShortcutItem *item = new ShortcutItem();
         item->setAccessibleName(info->name);
         connect(item, &ShortcutItem::requestUpdateKey, this, &ShortCutSettingWidget::requestUpdateKey);
+        if (QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+            connect(item, &ShortcutItem::waylandEditKeyFinshed, this, [ this ]{
+                if(m_waylandGrab && !m_waylandGrab->getRecordState())
+                    m_waylandGrab->onUnGrab();
+            });
+        }
         item->setShortcutInfo(info);
         item->setTitle(info->name);
         info->item = item;
@@ -285,6 +276,7 @@ void ShortCutSettingWidget::addShortcut(QList<ShortcutInfo *> list, ShortcutMode
             break;
         case ShortcutModel::Custom:
             connect(m_head, &SettingsHead::editChanged, item, &ShortcutItem::onEditMode);
+            qDebug() << Q_FUNC_INFO << item->curInfo()->name;
             m_customGroup->appendItem(item);
             m_customList.append(item);
 
@@ -382,25 +374,34 @@ void ShortCutSettingWidget::onSearchTextChanged(const QString &text)
 
 void ShortCutSettingWidget::onCustomAdded(ShortcutInfo *info)
 {
-    if (info) {
-        ShortcutItem *item = new ShortcutItem();
-        connect(item, &ShortcutItem::requestUpdateKey, this, &ShortCutSettingWidget::requestUpdateKey);
-        item->setShortcutInfo(info);
-        item->setTitle(info->name);
-        info->item = item;
+    if(info == nullptr)
+        return;
 
-        m_searchInfos[info->toString()] = info;
-
-        m_allList << item;
-
-        m_head->setVisible(true);
-        connect(m_head, &SettingsHead::editChanged, item, &ShortcutItem::onEditMode);
-        m_customGroup->appendItem(item);
-        m_customList.append(item);
-
-        connect(item, &ShortcutItem::requestRemove, this, &ShortCutSettingWidget::onDestroyItem);
-        connect(item, &ShortcutItem::shortcutEditChanged, this, &ShortCutSettingWidget::shortcutEditChanged);
+    // 防止自定义快捷键添加两次
+    for (auto item : m_customList) {
+        if(item->curInfo()->name == info->name){
+            return;
+        }
     }
+
+    qDebug() << Q_FUNC_INFO << info->name;
+    ShortcutItem *item = new ShortcutItem();
+    connect(item, &ShortcutItem::requestUpdateKey, this, &ShortCutSettingWidget::requestUpdateKey);
+    item->setShortcutInfo(info);
+    item->setTitle(info->name);
+    info->item = item;
+
+    m_searchInfos[info->toString()] = info;
+
+    m_allList << item;
+
+    m_head->setVisible(true);
+    connect(m_head, &SettingsHead::editChanged, item, &ShortcutItem::onEditMode);
+    m_customGroup->appendItem(item);
+    m_customList.append(item);
+
+    connect(item, &ShortcutItem::requestRemove, this, &ShortCutSettingWidget::onDestroyItem);
+    connect(item, &ShortcutItem::shortcutEditChanged, this, &ShortCutSettingWidget::shortcutEditChanged);
 }
 
 void ShortCutSettingWidget::onDestroyItem(ShortcutInfo *info)
@@ -443,6 +444,11 @@ void ShortCutSettingWidget::onSearchStringFinish(const QList<ShortcutInfo*> sear
 
         ShortcutItem *item = new ShortcutItem;
         connect(item, &ShortcutItem::requestUpdateKey, this, &ShortCutSettingWidget::requestUpdateKey);
+        if (QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+            connect(this, &ShortCutSettingWidget::changed, [ & ] {
+                onSearchTextChanged(m_searchText);
+            });
+        }
         item->setShortcutInfo(list[i]);
         item->setTitle(list[i]->name);
         item->setFixedHeight(36);
@@ -491,7 +497,7 @@ void ShortCutSettingWidget::onKeyEvent(bool press, const QString &shortcut)
 
     ShortcutInfo *conflict = m_model->getInfo(shortcut);
 
-    if (conflict == current && conflict->accels == current->accels) {
+    if (conflict && conflict->id == current->id && conflict->type == current->type && conflict->accels == current->accels) {
         current->item->setShortcut(current->accels);
         return;
     }
@@ -530,44 +536,54 @@ void ShortCutSettingWidget::onResetFinished()
 
 void ShortCutSettingWidget::onGrab(ShortcutInfo *info)
 {
-    waylandGrab->onGrab(info);
+    if (m_waylandGrab)
+        m_waylandGrab->onGrab(info);
 }
 
 void ShortCutSettingWidget::keyPressEvent(QKeyEvent *ke)
 {
-    if (!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive) || !waylandGrab->getZxgm()) {
+    if (!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)
+            || !m_waylandGrab || !m_waylandGrab->getZxgm()) {
         return;
     }
-    waylandGrab->setKeyValue(WaylandkeyMap[ke->key()]);
-    QString lastKey = waylandGrab->getLastKey();
-    QString keyValue = waylandGrab->getKeyValue();
+    unsigned int keKey = static_cast<unsigned int>(ke->key());
+    m_waylandGrab->setKeyValue(WaylandkeyMap[keKey]);
+    QString lastKey = m_waylandGrab->getLastKey();
+    QString keyValue = m_waylandGrab->getKeyValue();
 
-    onKeyEvent(true, waylandGrab->getRecordState() ? lastKey + keyValue : keyValue);
-    waylandGrab->setRecordState(true);
-    if (ke->key() == Qt::Key_Control || ke->key() == Qt::Key_Alt || ke->key() == Qt::Key_Shift || ke->key() == Qt::Key_Super_L) {
+    m_waylandGrab->setRecordState(true);
+    onKeyEvent(true, m_waylandGrab->getRecordState() ? lastKey + keyValue : keyValue);
+    if (keKey == Qt::Key_Control || keKey == Qt::Key_Alt
+            || keKey == Qt::Key_Shift || keKey == Qt::Key_Super_L || keKey == Qt::Key_Super_R) {
         lastKey += ("<" + keyValue.remove(keyValue.indexOf("_"), 2) + ">");
-        waylandGrab->setLastKey(lastKey);
+        m_waylandGrab->setLastKey(lastKey);
     }
     QWidget::keyPressEvent(ke);
 }
 
 void ShortCutSettingWidget::keyReleaseEvent(QKeyEvent *ke)
 {
-    if (!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive) || !waylandGrab->getZxgm()) {
+    if (!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)
+            || !m_waylandGrab || !m_waylandGrab->getZxgm() || !m_waylandGrab->getRecordState()) {
         return;
     }
-    QString lastKey = waylandGrab->getLastKey();
-    QString keyValue = waylandGrab->getKeyValue();
+    QString lastKey = m_waylandGrab->getLastKey();
+    QString keyValue = m_waylandGrab->getKeyValue();
     if (!lastKey.isEmpty()) {
-        if (ke->key() == Qt::Key_Control || ke->key() == Qt::Key_Alt || ke->key() == Qt::Key_Shift || ke->key() == Qt::Key_Super_L) {
+        if (WaylandkeyMap[Qt::Key_Control] == keyValue
+                || WaylandkeyMap[Qt::Key_Alt] == keyValue || WaylandkeyMap[Qt::Key_Shift] == keyValue) {
             onKeyEvent(false, "");
+        } else if (WaylandkeyMap[Qt::Key_Super_L] == keyValue || WaylandkeyMap[Qt::Key_Super_R] == keyValue) {
+            onKeyEvent(false, "Super_L");
         } else {
             onKeyEvent(false, lastKey + keyValue);
         }
+    } else {
+        onKeyEvent(false, "");
     }
-    waylandGrab->setLastKey("");
-    waylandGrab->setRecordState(false);
-    Q_EMIT changed(waylandGrab->getInfo()->id, waylandGrab->getInfo()->type);
-    waylandGrab->onUnGrab();
+    m_waylandGrab->setLastKey("");
+    m_waylandGrab->setRecordState(false);
+    Q_EMIT changed(m_waylandGrab->getInfo()->id, m_waylandGrab->getInfo()->type);
+    m_waylandGrab->onUnGrab();
     QWidget::keyReleaseEvent(ke);
 }
