@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     LiLinling <lilinling_cm@deepin.com>
- *
- * Maintainer: LiLinling <lilinling_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "personalizationgeneral.h"
 #include "perssonalizationthemewidget.h"
 #include "roundcolorwidget.h"
@@ -379,7 +363,7 @@ void PersonalizationGeneral::setModel(dcc::personalization::PersonalizationModel
             m_windowMovedSwitch->setChecked(checked);
             m_windowMovedSwitch->blockSignals(false);
         });
-        if (m_windowMovedSwitch && m_windowMovedSwitch->isChecked() != m_model->isMoveWindow()) {
+        if (m_windowMovedSwitch) {
             m_windowMovedSwitch->setChecked(m_model->isMoveWindow());
         }
 
@@ -469,6 +453,10 @@ void PersonalizationGeneral::updateWMSwitcher(bool checked)
         m_winRoundSlider->setVisible(checked || m_isWayland);
     }
 
+    if (m_windowMovedSwitch) {
+        m_windowMovedSwitch->setChecked(m_model->isMoveWindow());
+    }
+
     Q_EMIT windowMovedVisibleChanged(checked);
 }
 
