@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include <DFontSizeManager>
 #include <float.h>
 
@@ -115,7 +119,8 @@ void SystemUpdateItem::createDetailInfoItem(const QList<DetailInfo> &detailInfoL
     const QString &systemVersionType = DCC_NAMESPACE::IsServerSystem ? tr("Server") : tr("Desktop");
     DetailInfoItem *detailInfoItem = new DetailInfoItem(this);
     // 根据需求，将最后一个字符替换为0（原因是不想用户看到版本频繁的更新）
-    item.name.replace(item.name.length() - 1, 1, '0');
+    if (dccV20::IsProfessionalSystem)
+        item.name.replace(item.name.length() - 1, 1, '0');
     detailInfoItem->setTitle(systemVersionType + item.name);
     detailInfoItem->setDate(item.updateTime);
     detailInfoItem->setLinkData(item.link);
