@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2021 Deepin Technology Co., Ltd.
-*
-* Author:     guoyao <guoyao@uniontech.com>
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
-* Maintainer: guoyao <guoyao@uniontech.com>
-
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
 #include "searchmodel.h"
 #include "window/utils.h"
 
@@ -284,6 +268,9 @@ void SearchModel::loadxml(const QString module)
                 appendRow(new QStandardItem(
                     icon.value(), QString("%1 --> %2 / %3").arg(searchBoxStrcut->actualModuleName).arg(searchBoxStrcut->childPageName).arg(searchBoxStrcut->translateContent)));
             }
+
+            // 设置图标数据
+            setData(index(rowCount() - 1, 0), icon->name(), Qt::UserRole + 1);
         }
         else {
             appendChineseData(searchBoxStrcut);
