@@ -2,39 +2,39 @@
 <context>
     <name>PasswordWidget</name>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="62"/>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="145"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="45"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
         <source>Passwords do not match</source>
         <translation>Hasła nie pasują do siebie</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="71"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="54"/>
         <source>The hint is visible to all users. Do not include the password here.</source>
         <translation>Wskazówka będzie widoczna dla wszystkich użytkowników. Nie wprowadzaj tutaj swojego hasła.</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="89"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="72"/>
         <source>New Password</source>
         <translation>Nowe hasło</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="94"/>
         <source>Repeat Password</source>
         <translation>Powtórz hasło</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="119"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="102"/>
         <source>Password Hint</source>
         <translation>Wskazówka do hasła</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="129"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="112"/>
         <source>Required</source>
         <translation>Wymagane</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="130"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="113"/>
         <source>Optional</source>
         <translation>Opcjonalne</translation>
     </message>
@@ -42,69 +42,69 @@
 <context>
     <name>PwqualityManager</name>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="61"/>
         <source>Password cannot be empty</source>
         <translation>Pole na hasło nie może być puste</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="62"/>
         <source>Password must have at least %1 characters</source>
         <translation>Hasło musi zawierać co najmniej %1 znaków</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="80"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="63"/>
         <source>Password must be no more than %1 characters</source>
         <translation>Hasło nie może zawierać więcej niż %1 znaków </translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="81"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="64"/>
         <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
         <translation>Hasło musi zawierać tylko litery angielskie (z rozróżnieniem wielkich i małych), cyfry lub symbole specjalne (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="82"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="65"/>
         <source>No more than %1 palindrome characters please</source>
         <translation>Nie więcej niż %1 znaki palindromowe</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="83"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="66"/>
         <source>No more than %1 monotonic characters please</source>
         <translation>Nie więcej niż %1 znaki monotoniczne</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="84"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="67"/>
         <source>No more than %1 repeating characters please</source>
         <translation>Nie więcej niż %1 powtarzające się znaki</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="68"/>
         <source>The password should differ from the username</source>
         <translation>Hasło powinno różnić się od nazwy użytkownika</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="91"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="74"/>
         <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
         <translation>Hasło musi zawierać wielkie litery, małe litery, cyfry i symbole (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="92"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="75"/>
         <source>Password must not contain more than 4 palindrome characters</source>
         <translation>Hasło nie może zawierać więcej niż 4 znaki palindromowe</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="93"/>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="96"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="76"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
         <source>Do not use common words and combinations as password</source>
         <translation>Nie używaj popularnych słów i kombinacji jako hasła</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="94"/>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="95"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="77"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
         <source>Create a strong password please</source>
         <translation>Utwórz silne hasło</translation>
     </message>
     <message>
-        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="102"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
         <source>It does not meet password rules</source>
         <translation>Nie spełnia zasad dotyczących haseł</translation>
     </message>
@@ -112,7 +112,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/reset-password-dialog/utils.h" line="72"/>
+        <location filename="../src/reset-password-dialog/utils.h" line="55"/>
         <source>It cannot be empty</source>
         <translation>To pole nie może być puste</translation>
     </message>
@@ -120,60 +120,60 @@
 <context>
     <name>ResetPasswordDialog</name>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="119"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="102"/>
         <source>Resetting the password will clear the data stored in the keyring</source>
         <translation>Zresetowanie hasła spowoduje usunięcie danych zapisanych w keyringu</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="121"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="224"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="104"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="207"/>
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="130"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="113"/>
         <source>Security Questions</source>
         <translation>Pytania bezpieczeństwa</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="165"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="148"/>
         <source>Reset Password</source>
         <translation>Zresetuj hasło</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="149"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
         <source>Next</source>
         <translation>Następna</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="169"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="152"/>
         <source>Reset Password By UOS ID</source>
         <translation>Zresetuj hasło poprzez UOS ID</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="170"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="220"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="227"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="153"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="203"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="210"/>
         <source>Reset</source>
         <translation>Zresetuj</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="176"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="159"/>
         <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
         <translation>Zresetowanie hasła wyczyści wszystkie dane przechowywane w Twoim keyringu, przez co wymagane będzie ponowne logowanie. Prosimy o zapisanie wszystkich danych przed kontynuowaniem</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
         <source>Confirm and Reset</source>
         <translation>Potwierdź i Uruchom ponownie</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="302"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="285"/>
         <source>Successfully reset, please log in and unlock with the new password</source>
         <translation>Hasło zostało zresetowane pomyślnie, proszę zaloguj się przy użyciu nowego hasła. </translation>
     </message>
@@ -181,17 +181,17 @@
 <context>
     <name>SecurityLevelItem</name>
     <message>
-        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="73"/>
+        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="57"/>
         <source>Weak</source>
         <translation>Słabe</translation>
     </message>
     <message>
-        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="83"/>
+        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="67"/>
         <source>Medium</source>
         <translation>Średnie</translation>
     </message>
     <message>
-        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="93"/>
+        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="77"/>
         <source>Strong</source>
         <translation>Silne</translation>
     </message>
@@ -199,49 +199,49 @@
 <context>
     <name>SecurityQuestionsWidget</name>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="126"/>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="127"/>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="128"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="109"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="110"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="111"/>
         <source>Required</source>
         <translation>Wymagane</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="130"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="113"/>
         <source>What&apos;s the name of the city where you were born?</source>
         <translation>Jak nazywa się miasto, w którym się urodziłeś(aś)?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="114"/>
         <source>What&apos;s the name of the first school you attended?</source>
         <translation>Jak nazywa się pierwsza szkoła, do której uczęszczałeś(aś)?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="115"/>
         <source>Who do you love the most in this world?</source>
         <translation>Kogo kochasz najbardziej na świecie?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="116"/>
         <source>What&apos;s your favorite animal?</source>
         <translation>Jakie jest twoje ulubione zwierzę?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="117"/>
         <source>What&apos;s your favorite song?</source>
         <translation>Jaka jest twoja ulubiona piosenka?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="118"/>
         <source>What&apos;s your nickname?</source>
         <translation>Jaka jest twoja ksywka?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="185"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="168"/>
         <source>Wrong answer</source>
         <translation>Błędna odpowiedź</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="200"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="183"/>
         <source>Keep the answer under 30 characters</source>
         <translation>Utrzymaj odpowiedź w maksymalnie 30 znakach</translation>
     </message>
@@ -249,82 +249,82 @@
 <context>
     <name>UnionIDWidget</name>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="62"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="45"/>
         <source>Phone/Email</source>
         <translation>Telefon/E-mail</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="68"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="284"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="51"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="118"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="267"/>
         <source>Get Code</source>
         <translation>Zdobądź kod</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="88"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="71"/>
         <source>Connecting to the Internet...</source>
-        <translation>Łączenie się z Internetem...</translation>
+        <translation>Łączenie z Internetem...</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="100"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="83"/>
         <source>The user account is not linked to UOS ID</source>
         <translation>Konto użytkownika nie jest powiązane z UOS ID</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="113"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="96"/>
         <source>Network disconnected, please retry after connected</source>
         <translation>Sieć jest rozłączona, spróbuj ponownie po podłączeniu</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="133"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="134"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="116"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="117"/>
         <source>Required</source>
         <translation>Wymagane</translation>
     </message>
     <message>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="158"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="192"/>
         <source>Phone/Email format is incorrect</source>
         <translation>Format Telefonu/E-mail jest nieprawidłowy</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="229"/>
         <source>System error</source>
         <translation>Błąd systemu</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="248"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="231"/>
         <source>Login expired, please sign in to the UOS ID again</source>
         <translation>Sesja wygasła, zaloguj się ponownie do UOS ID</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="250"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="233"/>
         <source>Network error</source>
         <translation>Błąd sieci</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="252"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="235"/>
         <source>You have reached the number limit to get the code today</source>
         <translation>Przekroczono dzienny limit kodów jednorazowych</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="253"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="236"/>
         <source>The UOS ID is not linked to a user account</source>
         <translation>UOS ID nie jest połączone z kontem użytkownika</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="287"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="329"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="270"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="312"/>
         <source>Resend (%1s)</source>
         <translation>Wyślij ponownie (%1s)</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="349"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="332"/>
         <source>Failed to get the code</source>
         <translation>Nie udało się uzyskać kodu</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="374"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="357"/>
         <source>Wrong verification code</source>
         <translation>Nieprawidłowy kod weryfikacyjny</translation>
     </message>
